@@ -14,4 +14,13 @@ program intrinsics_30
     print *, range(i1), range(i2), ri3, ri4
     print *, range(r1), range(r2)
     print *, range(c1), range(c2)
+
+    if (ri3 /= 2) error stop
+    if (ri4 /= 4) error stop
+    if (range(i1) /= 9) error stop
+    if (range(i2) /= 18) error stop
+    if (range(r1) /= 37) error stop
+    if (range(r2) /= 307) error stop
+    if (range(c1) /= 37) error stop
+    if (range(c2) /= 307) error stop
 end program
