@@ -31,6 +31,7 @@ def single_test(test: Dict, verbose: bool, no_llvm: bool, skip_run_with_dbg: boo
     tokens = is_included("tokens")
     ast = is_included("ast")
     ast_indent = is_included("ast_indent")
+    ast_disable_style = is_included("ast_disable_style")
     ast_json = is_included("ast_json")
     ast_no_prescan = is_included("ast_no_prescan")
     ast_f90 = is_included("ast_f90")
@@ -48,6 +49,8 @@ def single_test(test: Dict, verbose: bool, no_llvm: bool, skip_run_with_dbg: boo
     asr_preprocess = is_included("asr_preprocess")
     asr_indent = is_included("asr_indent")
     asr_json = is_included("asr_json")
+    asr_openmp = is_included("asr_openmp")
+    asr_logical_casting = is_included("asr_logical_casting")
     mod_to_asr = is_included("mod_to_asr")
     llvm = is_included("llvm")
     cpp = is_included("cpp")
@@ -138,6 +141,7 @@ def single_test(test: Dict, verbose: bool, no_llvm: bool, skip_run_with_dbg: boo
             update_reference,
             verify_hash,
             extra_args)
+
     if ast_json:
         run_test(
             filename,
@@ -148,6 +152,16 @@ def single_test(test: Dict, verbose: bool, no_llvm: bool, skip_run_with_dbg: boo
             verify_hash,
             extra_args)
 
+    if ast_disable_style:
+        run_test(
+            filename,
+            "ast_disable_style",
+            "lfortran --show-ast --no-style-warnings --no-color {infile} -o {outfile}",
+            filename,
+            update_reference,
+            verify_hash,
+            extra_args)
+
     if ast_no_prescan:
         # Use free form with prescan disabled
         run_test(
@@ -358,6 +372,26 @@ def single_test(test: Dict, verbose: bool, no_llvm: bool, skip_run_with_dbg: boo
             verify_hash,
             extra_args)
 
+    if asr_openmp:
+        run_test(
+            filename,
+            "asr_openmp",
+            "lfortran --show-asr --no-color --openmp {infile} -o {outfile}",
+            filename,
+            update_reference,
+            verify_hash,
+            extra_args)
+
+    if asr_logical_casting:
+        run_test(
+            filename,
+            "asr_logical_casting",
+            "lfortran --show-asr --logical-casting --no-color {infile} -o {outfile}",
+            filename,
+            update_reference,
+            verify_hash,
+            extra_args)
+        
     if mod_to_asr:
         run_test(
             filename,
